==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/th.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "แบบสำรวจการใช้งาน",
    "Sent on: {on}" : "ส่งเมื่อ: {เมื่อ}",
    "An error occurred while sending your report." : "เกิดข้อผิดพลาดขณะส่งรายงาน",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "รายการ แอพ <em>(แต่ละแอพ: ชื่อ, รุ่น, ใช้งานได้หรือไม่)</em>",
    "Database environment <em>(type, version, database size)</em>" : "สภาพแวดล้อมของฐานข้อมูล<em>(ประเภท, รุ่น, ขนาด)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "การเข้ารหัสข้อมูล <em>(ใช้งานหรือไม่? โมดูลปกติคืออะไร)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "ข้อมูลเกี่ยว PHP <em>(version, memory limit, max. execution time, max. file size)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "ข้อมูลเกี่ยวกับ SERVER <em>(รุ่น, การใช้แคช, ล๊อค/ดูตัวอย่าง/ภาพโปรไฟล์ เปิดหรือไม่)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "สถิติ <em>(จำนวน: ไฟล์, ผู้ใช้งาน, พื้นที่เก็บแต่ละประเภท, คอมเมนท์ และ แท๊ก)</em>",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "หากคุณต้องการมีส่วนร่วมในการพัฒนา NextCloud กรุณาให้ข้อมูลเกี่ยวกับการติดตั้ง และการใช้งาน คุณสามารถปิดได้ทุกเมื่อ ที่หน้าตั้งค่า",
    "Not now" : "ไม่ใช่ตอนนี้",
    "Send usage" : "ส่งการใช้งาน",
    "Never" : "ไม่เคย",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "ร่วมพัฒนา NextCloud ด้วยการส่งข้อมูลเกี่ยวกับการติดตั้ง และการใช้งานของคุณ",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "เราให้ความสำคัญกับข้อมูลส่วนบุคคลของคุณ การส่งข้อมูลของคุณจะถูกปิดโดยค่าเริ่มต้น และเมื่อคุณเปิดใช้งาน ข้อมูลจะไม่ถูกระบุชื่อ คุณเลือกได้ว่าจะแชร์อะไร เมื่อได้รับข้อมูลใหม่ ข้อมูลเก่าจะถูกลบไป ส่งข้อมูลใหม่เพื่อลบข้อมูลเก่าที่เก็บอยู่ในเซิร์ฟเวอร์",
    "Send new report now" : "ส่งแบบสำรวจใหม่ ตอนนี้",
    "Send usage survey monthly" : "ส่งแบบสำรวจการใช้งานทุกเดือน",
    "Data to send" : "ข้อมูลที่ส่ง",
    "Last report" : "รายงานล่าสุด",
    "Sent on: %s" : "ส่งเมื่อ: %s",
    "You can help us to improve Nextcloud be sending us some data about your current setup and usage." : "ร่วมพัฒนา NextCloud ด้วยการส่งข้อมูลเกี่ยวกับการติดตั้ง และการใช้งานของคุณ",
    "We take your privacy seriously. The data are anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data are send and always see the last report send to us. When the server receives a new report of your instance, all entries from previous reports are removed. In case you disable one of the settings below, you can send a new report, to delete the data, that is currently stored on the server." : "เราให้ความสำคัญกับข้อมูลส่วนบุคคลของคุณ ข้อมูลจะไม่ถูกระบุชื่อ คุณสามารถเปิด / ปิด ได้ทุกเมื่อ ปกติจะปิดใช้งาน ด้านล่างนี้คุณสามารถปรับประเภทของข้อมูลที่จะส่ง และจะแสดงข้อมูลล่าสุดก่อนส่ง เมื่อเซิร์ฟเวอร์ได้รับข้อมูลใหม่ของคุณ ข้อมูลเก่าจะถูกลบออกทั้งหมด ในกรณีที่คุณปิดการใช้งานการตั้งค่าด้านล่างนี้คุณสามารถส่งรายงานใหม่ และลบข้อมูลที่เก็บอยู่ในเซิร์ฟเวอร์",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "ร่วมพัฒนา NextCloud ด้วยการส่งข้อมูลเกี่ยวกับการติดตั้ง และการใช้งานของคุณ",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "เราให้ความสำคัญกับข้อมูลส่วนบุคคลของคุณ ข้อมูลจะไม่ถูกระบุชื่อ คุณสามารถเปิด / ปิด ได้ทุกเมื่อ ปกติจะปิดใช้งาน ด้านล่างนี้คุณสามารถปรับประเภทของข้อมูลที่จะส่ง และจะแสดงข้อมูลล่าสุดก่อนส่ง เมื่อเซิร์ฟเวอร์ได้รับข้อมูลใหม่ของคุณ ข้อมูลเก่าจะถูกลบออกทั้งหมด ในกรณีที่คุณปิดการใช้งานการตั้งค่าด้านล่างนี้คุณสามารถส่งรายงานใหม่ และลบข้อมูลที่เก็บอยู่ในเซิร์ฟเวอร์"
},
"nplurals=1; plural=0;");

==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/th.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "แบบสำรวจการใช้งาน",
    "An error occurred while sending your report." : "เกิดข้อผิดพลาดขณะส่งรายงาน",
    "Database environment <em>(type, version, database size)</em>" : "สภาพแวดล้อมของฐานข้อมูล<em>(ประเภท, รุ่น, ขนาด)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "การเข้ารหัสข้อมูล <em>(ใช้งานหรือไม่? โมดูลปกติคืออะไร)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "ข้อมูลเกี่ยว PHP <em>(version, memory limit, max. execution time, max. file size)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "สถิติ <em>(จำนวน: ไฟล์, ผู้ใช้งาน, พื้นที่เก็บแต่ละประเภท, คอมเมนท์ และ แท๊ก)</em>",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "หากคุณต้องการมีส่วนร่วมในการพัฒนา NextCloud กรุณาให้ข้อมูลเกี่ยวกับการติดตั้ง และการใช้งาน คุณสามารถปิดได้ทุกเมื่อ ที่หน้าตั้งค่า",
    "Not now" : "ไม่ใช่ตอนนี้",
    "Send usage" : "ส่งการใช้งาน",
    "Never" : "ไม่เคย",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "ร่วมพัฒนา NextCloud ด้วยการส่งข้อมูลเกี่ยวกับการติดตั้ง และการใช้งานของคุณ",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "เราให้ความสำคัญกับข้อมูลส่วนบุคคลของคุณ การส่งข้อมูลของคุณจะถูกปิดโดยค่าเริ่มต้น และเมื่อคุณเปิดใช้งาน ข้อมูลจะไม่ถูกระบุชื่อ คุณเลือกได้ว่าจะแชร์อะไร เมื่อได้รับข้อมูลใหม่ ข้อมูลเก่าจะถูกลบไป ส่งข้อมูลใหม่เพื่อลบข้อมูลเก่าที่เก็บอยู่ในเซิร์ฟเวอร์",
    "Send new report now" : "ส่งแบบสำรวจใหม่ ตอนนี้",
    "Send usage survey monthly" : "ส่งแบบสำรวจการใช้งานทุกเดือน",
    "Data to send" : "ข้อมูลที่ส่ง",
    "Last report" : "รายงานล่าสุด",
    "Sent on: {on}" : "ส่งเมื่อ: {เมื่อ}",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "รายการ แอพ <em>(แต่ละแอพ: ชื่อ, รุ่น, ใช้งานได้หรือไม่)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "ข้อมูลเกี่ยวกับ SERVER <em>(รุ่น, การใช้แคช, ล๊อค/ดูตัวอย่าง/ภาพโปรไฟล์ เปิดหรือไม่)</em>",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "ร่วมพัฒนา NextCloud ด้วยการส่งข้อมูลเกี่ยวกับการติดตั้ง และการใช้งานของคุณ",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "เราให้ความสำคัญกับข้อมูลส่วนบุคคลของคุณ ข้อมูลจะไม่ถูกระบุชื่อ คุณสามารถเปิด / ปิด ได้ทุกเมื่อ ปกติจะปิดใช้งาน ด้านล่างนี้คุณสามารถปรับประเภทของข้อมูลที่จะส่ง และจะแสดงข้อมูลล่าสุดก่อนส่ง เมื่อเซิร์ฟเวอร์ได้รับข้อมูลใหม่ของคุณ ข้อมูลเก่าจะถูกลบออกทั้งหมด ในกรณีที่คุณปิดการใช้งานการตั้งค่าด้านล่างนี้คุณสามารถส่งรายงานใหม่ และลบข้อมูลที่เก็บอยู่ในเซิร์ฟเวอร์",
    "Sent on: %s" : "ส่งเมื่อ: %s"
},
"nplurals=1; plural=0;");
